@@ -8,10 +8,12 @@ import logging
 import os
 import sys
 import json
+import pkgutil
 
 import pkg_resources
 
-from .client import Client
+from lexicon.client import Client
+from lexicon import providers as providers_package
 
 #based off https://docs.python.org/2/howto/argparse.html
 
@@ -36,13 +38,10 @@ def BaseProviderParser():
     return parser
 
 def MainParser():
-    current_filepath = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'providers')
-    providers = [os.path.splitext(f)[0] for f in os.listdir(current_filepath) if os.path.isfile(os.path.join(current_filepath, f))]
-    providers = list(set(providers))
-    providers.remove('base')
-    providers.remove('__init__')
-    providers = [x for x in providers if not x.startswith('.')]
-
+    providers = []
+    for _, modname, _ in pkgutil.iter_modules(providers_package.__path__):
+        if modname != 'base':
+            providers.append(modname)
     providers = sorted(providers)
 
     parser = argparse.ArgumentParser(description='Create, Update, Delete, List DNS entries')
@@ -72,7 +71,12 @@ def generate_table_result(logger, output=None, without_header=None):
         logger.debug('Command output is not iterable, and then cannot be printed with --quiet parameter not enabled.')
         return None
 
-    array = [[row['id'], row['type'], row['name'], row['content'], row['ttl']] for row in output]
+    array = [[
+        row.get('id', ''), 
+        row.get('type', ''), 
+        row.get('name', ''), 
+        row.get('content', ''), 
+        row.get('ttl', '')] for row in output]
 
     # Insert header (insert before calculating the max width of each column to take headers size into account)
     if not without_header:
@@ -126,6 +130,7 @@ def main():
     logging.basicConfig(stream=sys.stdout, level=log_level, format='%(message)s')
 
     logger.debug('Arguments: %s', parsed_args)
+
     client = Client(vars(parsed_args))
     
     results = client.execute()
