@@ -11,10 +11,12 @@ from cryptography.hazmat.primitives import hashes, serialization
 from cryptography.hazmat.primitives.asymmetric import padding
 from base64 import urlsafe_b64encode, b64decode
 
-from .base import Provider as BaseProvider
+from lexicon.providers.base import Provider as BaseProvider
 
 LOGGER = logging.getLogger(__name__)
 
+NAMESERVER_DOMAINS = ['googledomains.com']
+
 # Implements the Google Cloud DNS provider.
 # This API is quite complicated to use, as it used some unique concepts compared to other providers.
 # First of all, it uses a full-fledged OAuth2 authentication, involving signing a JWT and retrieve a Bearer token.
@@ -391,4 +393,4 @@ class Provider(BaseProvider):
                                    headers={'Authorization': 'Bearer {0}'.format(self._token)})
 
         request.raise_for_status()
-        return request.json()
\ No newline at end of file
+        return request.json()
